@@ -16,14 +16,21 @@ public:
 
 private slots:
 	void slotConvertJewishToGregorian();
+	void slotCopyJewishToGregorian();
 	void slotConvertGregorianToJewish();
+	void slotCopyGregorianToJewish();
+	void slotCopyCurrentJewishDate();
 	void slotClose();
 	void slotAbout();
 
 private:
 	QString getGregorianMonthName(int month);
 	QString getJewishMonthName(int month);
+
+	void copyStringIntoClipboard(QString str);
 	
+	QClipboard* m_clipboard;
+
 	KComboBox* m_comboboxJewishToGregorianJewishDay;
 	KComboBox* m_comboboxJewishToGregorianJewishMonth;
 	KLineEdit* m_lineeditJewishToGregorianJewishYear;
